<?php


/**
 * Description of  SystemWizardDialog
 * Created by PhpStorm.
 * @package              
 * @createDate           
 * @lastModification     
 * @version              0.0.1
 * @author               
 * @copyright        (c) eDokumenty Sp. z o.o.
 */
class SystemWizardDialog extends DialogWizard {
    
    /**
     * @var array
     */
    protected static $stepsDefMethods = [
        'createClientNIP',
        'createClientData',
        'createClientUser',
        'createFinish',
    ];
    
    protected static $cMethods = [
    ];
    
    /**
     * SystemWizardDialog constructor.
     *
     * @param      $name
     * @param null $caption
     * @param int  $dstyle
     *
     * @throws CustomErrorException
     *
     */
    public function __construct($name, $caption = NULL, $dstyle = BS_DIALOG) {
        parent::__construct($name, $caption, $dstyle);
        
        $this->path = Application::makeRelativePath(__FILE__); 
        $this->HWND = $this->createHWND();
        $this->width = '800px';
        $this->height = '590px';

        $this->restoreStep(); //ważne aby to była ostatnia linia kontrukta
    }
    
    /**
     * open
     *
     * @param null $params
     * @param null $data
     *
     * @throws CustomErrorException
     */
    public function open($params = NULL, &$data = NULL) {
        parent::open($params, $data);
        
        $this->setSData($data);
        $this->create();
    }
    
    /**
     * createClientNIP
     *
     * @param $number
     *
     * @return Panel
     */
    protected function createClientNIP($number) {
        $panel = $this->getPanel($number);
        
        $this->headerPageText = ($number + 1).'. '.Translator::translate('Wprowadź nip, nazwę subdomeny, ilość użytkowników i datę wyłączenia systemu');
        
        $nip___ = new TextInput2($this->name.'nip');
        $lnip = $nip___->setLabel(Translator::translate('NIP'));
        $nip___->setRequired();
        $nip___->setNextTabIndex();
        $nip___->width = 'calc(50% - '.(Dialog::SPACE_LEFT + Dialog::SPACE_RIGHT).'px)';
        
        $subdom = new TextInput2($this->name.'subdom');
        $subdom->width = 'calc(50% - '.(Dialog::SPACE_LEFT + Dialog::SPACE_RIGHT).'px)';
        $lsubdom = $subdom->setLabel('Nazwa subdomeny');
        $lsubdom->setRequired();
        $subdom->setNextTabIndex();
        
        $enddat = new CalendarInput($this->name.'enddat');
        $enddat->dateFormat = 'y-m-d';
        $lenddat = $enddat->setLabel(Translator::translate('Data końca aktywacji'));
        $lenddat->setRequired();
        $enddat->setNextTabIndex();
        
        $usrnum = new NumberInput2($this->name.'usrnum');
        $usrnum->setLabel(Translator::translate('Ilość użytkowników '), Translator::translate('Maksymalna ilość użytkowników'));
        $usrnum->setRequired();
        $usrnum->setNextTabIndex();
        
        $language = new ExtSelect($this->name.'lang');
        $language->addItem('pl_PL', 'Polski');
        $language->addItem('en_EN', 'Angielski');
        $language->setLabel(Translator::translate('Język systemu'));
        $language->setRequired();
        $language->setNextTabIndex();
        
        $panel->addNext($nip___, 'nip');
        $panel->addNext($subdom, 'subdom', self::P_TO_RIGHT);
        $panel->addNext($usrnum, 'usrnum', self::P_LEFT);
        $panel->addNext($language, 'lang');
        
        $panel->addAfter($nip___, $enddat, 'enddat');
   
        return $panel;
    }
    
    /**
     * saveClientNIP
     *
     * @param array $wdata
     *
     * @throws Exception
     * @throws WidgetException
     */
    protected function saveClientNIP($wdata = []) {
        if (empty($wdata['nip'])) {
            throw new WidgetException($this->name.'nip', Translator::translate('Proszę wypełnić pole!'));
        }
        if (empty($wdata['subdom'])) {
            throw new WidgetException($this->name.'subdom', Translator::translate('Proszę wpisać adres'));
        }
        
        if (!preg_match('/^[a-z0-9]*$/', $wdata['subdom'])) {
            throw new WidgetException($this->name.'subdom', Translator::translate('Nazwa może składać się tylko z mały liter oraz cyfr!'));
        }
        
        if (empty($wdata['usrnum'])) {
            throw new WidgetException($this->name.'usrnum', Translator::translate('Proszę wpisać maksymalną ilość użytkowników'));
        }
        
        if (!preg_match('/^[0-9]*$/', $wdata['usrnum'])) {
            throw new WidgetException($this->name.'usrnum', Translator::translate('Proszę wpisać liczbę całkowitą'));
        }
        
        if (empty($wdata['enddat'])) {
            throw new WidgetException($this->name.'enddat', Translator::translate('Proszę wpisać wprowadzić date zakończenia aktywacji'));
        }
        
        if (empty($wdata['lang'])) {
            throw new WidgetException($this->name.'lang', Translator::translate('Proszę wypełnić pole!'));
        }

        $data = [];
        $data['nip___'] = $wdata['nip'];

        $this->setStepWData($this->currentPanel + 1, $data);
        $this->setSData($wdata);
    }
    
    /**
     * createClientData
     *
     * @param $number
     *
     * @return Panel
     */
    protected function createClientData($number) {
        $panel = $this->getPanel($number);
        $this->headerPageText = ($number + 1).'. '.Translator::translate('Dane zostały zaciągnięte z systemu GUS.').'</br>'.Translator::translate('Popraw dane, a następnie przejdź dalej');
        
        require_once(LIB_PATH.'widgets/FieldsSet.inc');
        require_once(LIB_PATH.'forms/TextInput2.inc');
        require_once(LIB_PATH.'forms/CheckBox2.inc');
        require_once(MOD_PATH.'Contacts2/view/ContactAddressViewForm.inc');
        
        $name_1 = new TextInput2($this->name.'name_1', 'text');
        $name_1->top = (Label::DEFAULT_HEIGHT + 2 * Dialog::SPACE_TOP).'px';
        $name_1->left = '0px';
        $name_1->width = '100%';
        $name_1->onKeyup = 'if(this.value.length==1)this.value.firstToUpper(this);';
        
        $lname = $name_1->setLabel(Translator::translate('Nazwa'));
        $lname->setRequired();
        
        $regon_ = new TextInput2($this->name.'regon_', 'text');
        $regon_->setLabel(Translator::translate('REGON'));
        
        $nip___ = new TextInput2($this->name.'nip___', 'text');
        $lnip = $nip___->setLabel(Translator::translate('NIP'));
        $lnip->setRequired();
        $nip___->setReadOnly();
        
        $ph_num = new TextInput2($this->name.'ph_num', 'text');
        $ph_num->width = 'calc(50% - '.(Dialog::SPACE1).'px)';
        $ph_num->setLabel(Translator::translate('Telefon'));
        $ph_num->placeholderIcon = 'eic eic-phone-filled';
        
        $faxnum = new TextInput2($this->name.'faxnum', 'text');
        $faxnum->setLabel(Translator::translate('Faks'));
        $faxnum->width = 'calc(50% - '.(Dialog::SPACE1).'px)';
        $faxnum->placeholderIcon = 'eic eic-fax-filled';
        
        $email_ = new TextInput2($this->name.'email_', 'text');
        $lemail = $email_->setLabel(Translator::translate('Email'));
        $lemail->setRequired();
        $email_->width = $name_1->width;
        $email_->placeholderIcon = 'eic eic-email-filled';
        
        $websit = new TextInput2($this->name.'websit', 'text');
        $websit->width = $name_1->width;
        $websit->setLabel(Translator::translate('WWW'), Translator::translate('Format strony bez http:// np.: www.moja-firma.pl'));
        
        $addressForm = new ContactAddressViewForm($this->name.'ADP', NULL, DS_CHILD);
        $addressForm->isSimple = TRUE;
        $addressForm->top = (Dialog::SPACE_TOP).'px';
        $addressForm->width = 'calc(100% + '.(Dialog::SPACE_LEFT + Dialog::SPACE_RIGHT).'px)';
        $addressForm->left = '-'.Dialog::SPACE_LEFT.'px';
        $addressForm->height = '382px';
        $addressForm->style = 'overflow: hidden;';
        $addressForm->open(0);
        
        $leftColumn = new FieldsSet($this->name.'headerRowLeftColumn', FieldsSet::STYLE4);
        $leftColumn->setLabelBlock('eic eic-edit-property');
        $leftColumn->setLabelText(Translator::translate('Podstawowe dane'));
        $leftColumn->clearPositionString(TRUE);
        $leftColumn->width = 'calc(50% - '.(Dialog::SPACE_LEFT + Dialog::SPACE_RIGHT).'px)';
        $leftColumn->height = '100%';
        
        $rightColumn = new FieldsSet($this->name.'headerRowRightColumn', FieldsSet::STYLE4);
        $rightColumn->setLabelBlock('eic eic-map-marker');
        $rightColumn->setLabelText(Translator::translate('Dane adresowe'));
        $rightColumn->clearPositionString(TRUE);
        $rightColumn->width = $leftColumn->width;
        $rightColumn->height = '100%';
        
        $leftColumn->addNext($name_1, 'name_1');
        $leftColumn->addNext($nip___, 'nip___');
        $leftColumn->addNext($regon_, 'regon_');
        $leftColumn->addNext($ph_num, 'ph_num');
        
        $leftColumn->addNext($email_, 'email_');
        $leftColumn->addNext($websit, 'websit');
        
        $leftColumn->addAfter($ph_num, $faxnum, 'faxnum', Widget::P_TO_RIGHT_R);
        
        $rightColumn->add($addressForm);
        
        $panel->addNext($leftColumn, NULL, Widget::P_TO_LEFT);
        $panel->addNext($rightColumn, NULL, Widget::P_TO_RIGHT);
        
        return $panel;
    }
    
    /**
     * saveClientData
     *
     * @param array $wData
     *
     * @throws WidgetException
     */
    protected function saveClientData($wData = []) {
        $sData = $this->getSData();

        
        $this->setSData(['client' => $wData]);
    }
    
    /**
     * createClientUser
     *
     * @param $number
     *
     * @return Panel
     */
    protected function createClientUser($number) {
        $panel = $this->getPanel($number);
        $this->setHeaderStep(($number + 1).'. '.Translator::translate('Dodaj nowego użytkownika dla klienta'), 'eic eic-user');
        
        $sdata = $this->getSData();
        
        $usrnam = new TextInput2($this->name.'usrnam');
        $usrnam->width = 'calc(100% - '.(Dialog::SPACE_LEFT + Dialog::SPACE_RIGHT).'px)';
        $lusrnam = $usrnam->setLabel(Translator::translate('Nazwa użytkownika (adres email)'));
        $lusrnam->setRequired();
        
        $firnam = new TextInput2($this->name.'firnam');
        $firnam->setLabel(Translator::translate('Imię'));
        
        $lasnam = new TextInput2($this->name.'lasnam');
        $lasnam->setLabel(Translator::translate('Nazwisko'));
        
        $withoutSendMailClient = new CheckBox2($this->name.'withoutSendMailClient', FALSE, TRUE);
        $withoutSendMailClient->setLeftCaption(Translator::translate('Załóż clouda bez powiadamiania klienta'));
        $withoutSendMailClient->addHTMLAttr('onchange', 'App.'.$this->name.'PasswdAction();');
        
        $passwd1 = new PasswordInput($this->name.'passwd1');
        $passwd1->setLabel(Translator::translate('Hasło'));
        
        $passwd2 = new PasswordInput($this->name.'passwd2');
        $passwd2->setLabel(Translator::translate('Powtórz hasło'));
        
        JScript::add('App.'.$this->name.'PasswdAction = function (){
            if ($("'.$withoutSendMailClient->name.'_chk").checked) {
                $("'.$this->name.'passwd1_wb").style.display = \'block\';
                $("'.$this->name.'passwd1_l").style.display = \'block\';
                $("'.$this->name.'passwd2_wb").style.display = \'block\';
                $("'.$this->name.'passwd2_l").style.display = \'block\';
                
                $("'.$this->name.'usrnam").value = \'admin_'.$sdata['subdom'].'\';
                
            } else {
                $("'.$this->name.'passwd1_wb").style.display = \'none\';
                $("'.$this->name.'passwd1_l").style.display = \'none\';
                $("'.$this->name.'passwd2_wb").style.display = \'none\';
                $("'.$this->name.'passwd2_l").style.display = \'none\';
                
                $("'.$this->name.'usrnam").value = \'\';
            }
        };App.'.$this->name.'PasswdAction ();');
        
        
        $panel->addNext($usrnam, 'usrnam');
        $panel->addNext($firnam, 'firnam');
        $panel->addNext($lasnam, 'lasnam');
        
        $panel->addNext($withoutSendMailClient, 'withoutSend');
        
        $panel->addNext($passwd1, 'passwd1');
        $panel->addNext($passwd2, 'passwd2');
        
        
        if (isset($sdata['client']['email_'])) {
            $this->stepWData[$number] = [
                'usrnam' => $sdata['client']['email_'],
                'firnam' => 'Administrator',
                'lasnam' => 'Systemu ',
            ];
        }
        
        
        $this->setNextButton(Translator::translate('Utwórz'));
        return $panel;
    }
    
    /**
     * saveClientUser
     *
     * @param array $wData
     *
     * @throws WidgetException
     */
    protected function saveClientUser($wData = []) {
        if (empty($wData['usrnam'])) {
            throw new WidgetException($this->name.'usrnam', Translator::translate('Pole wymagane!'));
        }
        
        $this->setSData([
            'userClient'              => [
                'firnam' => $wData['firnam'],
                'lasnam' => $wData['lasnam'],
                'usrnam' => $wData['usrnam'],
                'passwd' => $passwd,
            ]            
        ]);
    }
    
    /**
     * createFinish
     *
     * @param $number
     *
     * @return Panel
     *
     * @throws WidgetException
     */
    protected function createFinish($number) {
        $panel = $this->getPanel($number);
        $this->headerPageText = Translator::translate('Wszystkie potrzebne informacje zostały już zebrane.').'<br>'.Translator::translate('System teraz utworzy nowe biuro księgowe');
       
        $sdata = $this->getSData();
      
        
        return $panel;
    }
}